prefix=/usr/X11R6
exec_prefix=${prefix}

if test "${prefix}/include" != /usr/include ; then
  LIBGLADE_INCLUDEDIR="-I${prefix}/include -I/usr/local/include/gnome-xml"
else
  LIBGLADE_INCLUDEDIR="-I/usr/local/include/gnome-xml"
fi
LIBGLADE_LIBDIR="-L${exec_prefix}/lib -L/usr/X11R6/lib -L/usr/local/lib"
LIBGLADE_LIBS="-lglade-gnome -lglade -L/usr/local/lib -lxml -lz -lXpm -lgnomeui -lart_lgpl -lgdk_imlib -ltiff -ljpeg -lungif -lpng -lz -lSM -lICE -lgtk12 -lgdk12 -lgmodule12 -lxpg4 -lXext -lX11 -lgnome -lgnomesupport -lintl -lesd -laudiofile -lm -lglib12 -ldl"
MODULE_VERSION="libglade-0.16"

